import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { DescribeLifecycleHooksAnswer, DescribeLifecycleHooksType } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeLifecycleHooksCommand}.
 */
export interface DescribeLifecycleHooksCommandInput extends DescribeLifecycleHooksType {
}
/**
 * @public
 *
 * The output of {@link DescribeLifecycleHooksCommand}.
 */
export interface DescribeLifecycleHooksCommandOutput extends DescribeLifecycleHooksAnswer, __MetadataBearer {
}
declare const DescribeLifecycleHooksCommand_base: {
    new (input: DescribeLifecycleHooksCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeLifecycleHooksCommandInput, DescribeLifecycleHooksCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DescribeLifecycleHooksCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeLifecycleHooksCommandInput, DescribeLifecycleHooksCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets information about the lifecycle hooks for the specified Auto Scaling group.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DescribeLifecycleHooksCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DescribeLifecycleHooksCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // DescribeLifecycleHooksType
 *   AutoScalingGroupName: "STRING_VALUE", // required
 *   LifecycleHookNames: [ // LifecycleHookNames
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new DescribeLifecycleHooksCommand(input);
 * const response = await client.send(command);
 * // { // DescribeLifecycleHooksAnswer
 * //   LifecycleHooks: [ // LifecycleHooks
 * //     { // LifecycleHook
 * //       LifecycleHookName: "STRING_VALUE",
 * //       AutoScalingGroupName: "STRING_VALUE",
 * //       LifecycleTransition: "STRING_VALUE",
 * //       NotificationTargetARN: "STRING_VALUE",
 * //       RoleARN: "STRING_VALUE",
 * //       NotificationMetadata: "STRING_VALUE",
 * //       HeartbeatTimeout: Number("int"),
 * //       GlobalTimeout: Number("int"),
 * //       DefaultResult: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeLifecycleHooksCommandInput - {@link DescribeLifecycleHooksCommandInput}
 * @returns {@link DescribeLifecycleHooksCommandOutput}
 * @see {@link DescribeLifecycleHooksCommandInput} for command's `input` shape.
 * @see {@link DescribeLifecycleHooksCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To describe your lifecycle hooks
 * ```javascript
 * // This example describes the lifecycle hooks for the specified Auto Scaling group.
 * const input = {
 *   "AutoScalingGroupName": "my-auto-scaling-group"
 * };
 * const command = new DescribeLifecycleHooksCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "LifecycleHooks": [
 *     {
 *       "AutoScalingGroupName": "my-auto-scaling-group",
 *       "DefaultResult": "ABANDON",
 *       "GlobalTimeout": 172800,
 *       "HeartbeatTimeout": 3600,
 *       "LifecycleHookName": "my-lifecycle-hook",
 *       "LifecycleTransition": "autoscaling:EC2_INSTANCE_LAUNCHING",
 *       "NotificationTargetARN": "arn:aws:sns:us-west-2:123456789012:my-sns-topic",
 *       "RoleARN": "arn:aws:iam::123456789012:role/my-auto-scaling-role"
 *     }
 *   ]
 * }
 * *\/
 * // example id: autoscaling-describe-lifecycle-hooks-1
 * ```
 *
 */
export declare class DescribeLifecycleHooksCommand extends DescribeLifecycleHooksCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeLifecycleHooksType;
            output: DescribeLifecycleHooksAnswer;
        };
        sdk: {
            input: DescribeLifecycleHooksCommandInput;
            output: DescribeLifecycleHooksCommandOutput;
        };
    };
}
